/**
 * @license
 * Copyright (c) 2016 Łukasz Kurowski <crackcomm@gmail.com>
 */
"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
const express = require("express");
const escore_runtime_1 = require("escore-runtime");
const middlewares_1 = require("./middlewares");
__export(require("./middlewares"));
class Server {
    constructor(opts) {
        /** Express server */
        this.http = express();
        /** Application modules */
        this.registry = new escore_runtime_1.Registry();
        /** Runtime */
        this.runtime = new escore_runtime_1.Runtime(this.registry);
        /** Express middlewares */
        this.middlewares = [];
        this.opts = opts;
        middlewares_1.middlewares.forEach((constructor) => this.http.use(constructor(this.opts.middlewares)));
    }
    /**
     * Starts server.
     */
    start() {
        this.middlewares.forEach((middleware) => this.http.use(middleware(this.opts.middlewares)));
        this.http.listen(this.opts.port);
    }
}
exports.Server = Server;
function create(opts) {
    return new Server(opts);
}
exports.create = create;
;
